@@ -5,6 +5,7 @@ pub mod ui;
 use self::actions::Actions;
 use self::state::AppState;
 use crate::app::actions::Action;
+
 use crate::inputs::key::Key;
 use crate::io::IoEvent;
 
@@ -14,14 +15,15 @@ pub enum AppReturn {
     Continue,
 }
 
-pub struct App {
+#[derive(Clone)]
+pub struct App<'a> {
     io_tx: tokio::sync::mpsc::Sender<IoEvent>,
     actions: Actions,
     is_loading: bool,
-    state: AppState,
+    pub state: AppState<'a>,
 }
 
-impl App {
+impl<'a> App<'a> {
     pub fn new(io_tx: tokio::sync::mpsc::Sender<IoEvent>) -> Self {
         let actions = vec![Action::Quit].into();
         let is_loading = false;
@@ -40,11 +42,15 @@ impl App {
             match action {
                 Action::Quit => AppReturn::Exit,
                 Action::Increment => {
-                    self.state.increment_index();
+                    self.dispatch(IoEvent::Increment).await;
                     AppReturn::Continue
                 }
                 Action::Decrement => {
-                    self.state.decrement_index();
+                    self.dispatch(IoEvent::Decrement).await;
+                    AppReturn::Continue
+                }
+                Action::Show => {
+                    self.dispatch(IoEvent::LoadImage).await;
                     AppReturn::Continue
                 }
             }
@@ -67,10 +73,15 @@ impl App {
     pub fn actions(&self) -> &Actions {
         &self.actions
     }
+
     pub fn state(&self) -> &AppState {
         &self.state
     }
 
+    pub fn state_mut(&'a mut self) -> &'a mut AppState {
+        &mut self.state
+    }
+
     pub fn is_loading(&self) -> bool {
         self.is_loading
     }
@@ -78,7 +89,13 @@ impl App {
     pub fn initialized(&mut self) {
         let args: Vec<String> = std::env::args().collect();
         let path = if args[1..].is_empty() { "./" } else { &args[1] };
-        self.actions = vec![Action::Quit, Action::Increment, Action::Decrement].into();
+        self.actions = vec![
+            Action::Quit,
+            Action::Increment,
+            Action::Decrement,
+            Action::Show,
+        ]
+        .into();
         self.state = AppState::initialized(path);
     }
 
