@@ -1,9 +1,9 @@
 pub mod handler;
 
-use std::time::Duration;
-
 #[derive(Debug, Clone)]
 pub enum IoEvent {
     Initialize,
-    Sleep(Duration),
+    Increment,
+    Decrement,
+    LoadImage,
 }
