@@ -7,24 +7,36 @@ pub mod utils;
 use crate::app::ui;
 use app::{App, AppReturn};
 use eyre::Result;
-use inputs::events::Events;
-use inputs::InputEvent;
+use inputs::{
+    events::Events,
+    InputEvent,
+};
 use io::IoEvent;
-use std::io::stdout;
-use std::sync::Arc;
-use std::time::Duration;
-use tui::backend::CrosstermBackend;
-use tui::Terminal;
+use std::{
+    io::stdout,
+    sync::Arc,
+    time::Duration,
+};
+use tui::{
+    backend::CrosstermBackend,
+    Terminal,
+};
+use crossterm::{
+    event::{DisableMouseCapture, EnableMouseCapture},
+    execute,
+    terminal::{disable_raw_mode, enable_raw_mode, LeaveAlternateScreen, EnterAlternateScreen},
+};
 
-pub async fn start_ui(app: &Arc<tokio::sync::Mutex<App>>) -> Result<()> {
-    let stdout = stdout();
-    crossterm::terminal::enable_raw_mode()?;
+pub async fn start_ui<'a>(app: &Arc<tokio::sync::Mutex<App<'a>>>) -> Result<()> {
+    let mut stdout = stdout();
+    enable_raw_mode()?;
+    execute!(stdout, EnterAlternateScreen, EnableMouseCapture)?;
     let backend = CrosstermBackend::new(stdout);
     let mut terminal = Terminal::new(backend)?;
     terminal.clear()?;
     terminal.hide_cursor()?;
 
-    let tick_rate = Duration::from_millis(200);
+    let tick_rate = Duration::from_millis(100);
     let mut events = Events::new(tick_rate);
 
     {
@@ -35,7 +47,7 @@ pub async fn start_ui(app: &Arc<tokio::sync::Mutex<App>>) -> Result<()> {
     loop {
         let mut app = app.lock().await;
 
-        terminal.draw(|rect| ui::draw(rect, &app))?;
+        terminal.draw(|rect| ui::draw(rect, &mut app))?;
 
         let result = match events.next().await {
             InputEvent::Input(key) => app.do_action(key).await,
@@ -48,9 +60,13 @@ pub async fn start_ui(app: &Arc<tokio::sync::Mutex<App>>) -> Result<()> {
         }
     }
 
-    terminal.clear()?;
+    disable_raw_mode()?;
+    execute!(
+        terminal.backend_mut(),
+        LeaveAlternateScreen,
+        DisableMouseCapture
+    )?;
     terminal.show_cursor()?;
-    crossterm::terminal::disable_raw_mode()?;
 
     Ok(())
 }
